@@ -556,7 +556,7 @@ void MetabarWidget::addEntry(DOM::DOMString &html, const QString name, const QSt
     html += " style=\"display: none;\"";
   }
   
-  html += "><nobr><a";
+  html += "><a";
   
   if(!id.isNull() && !id.isEmpty()){
     html += " id=\"";
@@ -576,7 +576,7 @@ void MetabarWidget::addEntry(DOM::DOMString &html, const QString name, const QSt
   html += getIconPath(icon);
   html += ");\">";
   html += name;
-  html += "</a></nobr></ul>";
+  html += "</a></ul>";
 }
 
 void MetabarWidget::setTheme()
